@@ -148,9 +148,7 @@ class ModelThemes(ModelTemplate):
         Treats the data to be inserted into the model
         """
 
-        emb = HashingVectorizer(n_features=2**14,
-                                strip_accents=None,
-                                lowercase=False).fit_transform(data)
+        emb = HashingVectorizer(n_features=2**14).fit_transform(data)
 
         return emb
 
